@@ -1,6 +1,8 @@
-from base import QuickbooksManagedObject, QuickbooksTransactionEntity
+from six import python_2_unicode_compatible
+from .base import QuickbooksManagedObject, QuickbooksTransactionEntity, Ref
 
 
+@python_2_unicode_compatible
 class PaymentMethod(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: The PaymentMethod entity provides the method of payment for received goods. Delete is achieved by setting the
@@ -19,6 +21,11 @@ class PaymentMethod(QuickbooksManagedObject, QuickbooksTransactionEntity):
         self.Type = ""
         self.Active = True
 
-    def __unicode__(self):
+    def __str__(self):
         return self.Name
 
+    def to_ref(self):
+        ref = Ref()
+        ref.name = self.Name
+        ref.type = self.qbo_object_name
+        ref.value = self.Id
